==> robbyson-library-1.0.11.tgz: package/libmongodb/database.js <==
var mongoose = require('mongoose');
var promise = require('promise');
mongoose.Promise = promise;

var db = {};
db.connect = function(contratante, aplicacao, callback_success, callback_error) {

    if (!global.DicionarioConexoes) {

        global.DicionarioConexoes = [];

        contratante.contratantesIds.foreach(function(contratanteId) {

            var conexao = {};
            var connection = contratante.getDataBaseConnection(contratanteId, 'MONGODB', aplicacao);

            var url = 'mongodb://' + connection.Servidor + "/" + connection.BancoDeDados;
            var auth = {
                "user": connection.Usuario,
                "password": connection.Senha
            };
            conexao.models = [];
            conexao.contratanteId = contratanteId;
            conexao.instancia = mongoose.createConnection(url, { config: { autoIndex: true }, auth: auth }, function(error, teste) {
                if (error) {
                    console.log("Erro ao conectar no MongoDb: " + error);
                    if (callback_error)
                        callback_error();
                    process.exit();
                } else {
                    console.log("MongoDb conectado.");
                    if (callback_success)
                        callback_success();
                }
            });

            global.DicionarioConexoes.push(conexao);

        });
    }
};

db.staticConnect = function(connectionConfig, name, callback_success, callback_error) {

    if (!global.DicionarioConexoesEstaticas) {

        global.DicionarioConexoesEstaticas = [];

        var conexao = {};
        var url = 'mongodb://' + connectionConfig.host + ":" + connectionConfig.port + "/" + connectionConfig.database;
        var auth = {
            "user": connectionConfig.user,
            "password": connectionConfig.pass
        };
        conexao.models = [];
        conexao.name = name;
        conexao.instancia = mongoose.createConnection(url, { config: { autoIndex: true }, auth: auth }, function(error, teste) {
            if (error) {
                console.log("Erro ao conectar no MongoDb: " + error);
                if (callback_error)
                    callback_error();
                process.exit();
            } else {
                console.log("MongoDb conectado.");
                if (callback_success)
                    callback_success();
            }
        });

        global.DicionarioConexoesEstaticas.push(conexao);
    }
};
/**
 * Este método sera retirado favor utilizar o `staticConnect`
 * @param {string} url 
 */
db.connectToRobbyson = function(url) {
    if (!mongoose.connection.readyState) {
        console.log(url);
        //it is recommended autoIndex be disabled in production since index creation can cause a significant performance impact.
        mongoose.connect(url, { config: { autoIndex: true }, useMongoClient: true }, function(error) {
            if (error) {
                console.log("Erro ao conectar no MongoDb: " + error);
            } else {
                console.log("MongoDb conectado!");
            }
        });
    }
};

module.exports = db;

==> robbyson-library-1.0.12.tgz: package/libmongodb/database.js <==
var mongoose = require('mongoose');
var promise = require('promise');
mongoose.Promise = promise;

var db = {};
db.connect = function(contratante, aplicacao, callback_success, callback_error) {

    if (!global.DicionarioConexoes) {

        global.DicionarioConexoes = [];

        contratante.contratantesIds.forEach(function(contratanteId) {

            var conexao = {};
            var connection = contratante.getDataBaseConnection(contratanteId, 'MONGODB', aplicacao);

            var url = 'mongodb://' + connection.Servidor + "/" + connection.BancoDeDados;
            var auth = {
                "user": connection.Usuario,
                "password": connection.Senha
            };
            conexao.models = [];
            conexao.contratanteId = contratanteId;
            conexao.instancia = mongoose.createConnection(url, { config: { autoIndex: true }, auth: auth }, function(error, teste) {
                if (error) {
                    console.log("Erro ao conectar no MongoDb: " + error);
                    if (callback_error)
                        callback_error();
                    process.exit();
                } else {
                    console.log("MongoDb conectado.");
                    if (callback_success)
                        callback_success();
                }
            });

            global.DicionarioConexoes.push(conexao);

        });
    }
};

db.staticConnect = function(connectionConfig, name, callback_success, callback_error) {

    if (!global.DicionarioConexoesEstaticas) {

        global.DicionarioConexoesEstaticas = [];

        var conexao = {};
        var url = 'mongodb://' + connectionConfig.host + ":" + connectionConfig.port + "/" + connectionConfig.database;
        var auth = {
            "user": connectionConfig.user,
            "password": connectionConfig.pass
        };
        conexao.models = [];
        conexao.name = name;
        conexao.instancia = mongoose.createConnection(url, { config: { autoIndex: true }, auth: auth }, function(error, teste) {
            if (error) {
                console.log("Erro ao conectar no MongoDb: " + error);
                if (callback_error)
                    callback_error();
                process.exit();
            } else {
                console.log("MongoDb conectado.");
                if (callback_success)
                    callback_success();
            }
        });

        global.DicionarioConexoesEstaticas.push(conexao);
    }
};
/**
 * Este método sera retirado favor utilizar o `staticConnect`
 * @param {string} url 
 */
db.connectToRobbyson = function(url) {
    if (!mongoose.connection.readyState) {
        console.log(url);
        //it is recommended autoIndex be disabled in production since index creation can cause a significant performance impact.
        mongoose.connect(url, { config: { autoIndex: true }, useMongoClient: true }, function(error) {
            if (error) {
                console.log("Erro ao conectar no MongoDb: " + error);
            } else {
                console.log("MongoDb conectado!");
            }
        });
    }
};

module.exports = db;
